
# Slot: birth_date


Date on which a person is born

URI: [nwb_schema_language:birth_date](https://w3id.org/p2p_ld/nwb-schema-language/birth_date)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Date](types/Date.md)

## Parents


## Children


## Used by

 * [Namespaces](Namespaces.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | schema:birthDate |

